@@ -2,5 +2,5 @@ from PyMolecules import SingleLinkedList, DoubleLinkedList,SingleCircularLinkedL
 
 
 __author__ = "Yokesh Bollineni"
-__version__ = "2.0.1"
-__what_is_new__ = "Added SCLL class, Bug fix in size() method of DLL class"
+__version__ = "2.0.2"
+__what_is_new__ = "Removal of junk code in the version 2.0.1"
